@@ -1,13 +1,10 @@
-# $Id: /mirror/perl/Swarmage/trunk/lib/Swarmage.pm 36883 2007-12-25T04:15:57.892026Z daisuke  $
+# $Id: /mirror/perl/Swarmage/trunk/lib/Swarmage.pm 2425 2007-09-03T10:56:40.325353Z daisuke  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
-
 package Swarmage;
-use strict;
-use warnings;
-use Swarmage::Drone;
-our $VERSION = '0.01000';
+use vars qw($VERSION);
+$VERSION = '0.00003';
 
 1;
 
@@ -19,15 +16,13 @@ Swarmage - A Distributed Job Queue
 
 =head1 SYNOPSIS
 
-  use Swarmage
+  swarmage task insert --config=config.yml
+  swarmage worker --module=MyApp::Worker
 
 =head1 DESCRIPTION
 
-This is a rewrite of previous Swarmage releases. So we're back to pre-alpha.
-
-Swarmage brings you a complete Controlled Job Queue environment for high
-performance, distributed tasks. Swarmage uses POE's asynchronous engine
-to make a non-blocking worker possible.
+XXX Warning: Alpha grade software. All API still subject to change.
+RFCs are welcome and will be considered ASAP XXX
 
 Swarmage is a simple distributed job queue system.
 
@@ -68,33 +63,53 @@ On some other host (or, it could as well be the same host):
 You execute this code, and the worker will keep on waiting for 'do_something_interesting' tasks,
 and will execute them when it gets a chance. 
 
-A Swarmage Cell is the smallest unit of operation in Swarmage, and it looks
-something like this:
+The above code can also be written in a more object oriented manner.
+Just override the work_once subroutine
 
   package MyApp::Worker;
   use strict;
   use base qw(Swarmage::Worker);
 
-There is a Global Queue, which Drones attatch to. This is where users typically
-queue their tasks. Drones take tasks that their Workers can handle. This is
-done by specifying which Workers can handle which types of tasks in the
-initialization of Drones.
+  __PACKAGE__->register_abilities('do_something_interesting');
 
-Once the Drone receives possibly multiple tasks from the Global Queue, the
-tasks are inserted into what's called a Local Queue. Drones keep track of
-what tasks are currently handle by looking at this Local Queue, and in
-turn Workers attempt to grab tasks the Local Queue.
+  sub work_once { "actual code" }
 
-Workers only knows about the Local Queue. This is to avoid unnecessary polling
-by the Workers to the Global Queue. Workers can also pass tasks between
-other Workers in the local Drone group by enqueuing new tasks to the Local
-Queue.
+  # in your worker script
+  use strict;
+  use MyApp::Worker;
 
-Once the task is completed, the Drone is notified, and the task will be
-finalized.
+  my $worker = MyApp::Worker->new(
+    hostname => "message.bus.hostname",
+    login    => "foo",
+    passcode => "bar",
+  );
+  $worker->work;
 
-Please consult the documentation for Swarmage::Drone and Swarmage::Worker for
-more details on how the components interact with each other
+Actually, once you write MyApp::Worker, you can just use the swarmage script
+that comes with this distribution:
+
+  swarmage worker --module=MyApp::Worker \
+    --hostname=message.bus.hostname \
+    --login=foo \
+    --passcode=bar
+
+...And if you don't have to do any special pre-processing, you can just
+specify a task within a config file 
+
+  swarmage task insert --config=foo.yml
+
+=head1 TASKS
+
+Tasks are simply a combination of 'task_class', and a set of arbitrary data.
+It's completely up to the client and the worker to make any sense out of it.
+
+=head1 MESSAGE BUS
+
+Swarmage relies on message queues such as ActiveMQ as the underlying
+message layer.
+
+There's an unfinished attempt at making a small scale DBIC-based message layer,
+but so far I have no plans to work on it. Patches are more than welcome
 
 =head1 AUTHOR
 
